==> rds-1.182.0-sources.jar: software/amazon/awscdk/services/rds/DatabaseClusterEngine.java <==
package software.amazon.awscdk.services.rds;

/**
 * A database cluster engine.
 * <p>
 * Provides mapping to the serverless application
 * used for secret rotation.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * Vpc vpc;
 * ServerlessCluster cluster = ServerlessCluster.Builder.create(this, "AnotherCluster")
 *         .engine(DatabaseClusterEngine.AURORA_POSTGRESQL)
 *         .parameterGroup(ParameterGroup.fromParameterGroupName(this, "ParameterGroup", "default.aurora-postgresql10"))
 *         .vpc(vpc)
 *         .scaling(ServerlessScalingOptions.builder()
 *                 .autoPause(Duration.minutes(10)) // default is to pause after 5 minutes of idle time
 *                 .minCapacity(AuroraCapacityUnit.ACU_8) // default is 2 Aurora capacity units (ACUs)
 *                 .maxCapacity(AuroraCapacityUnit.ACU_32)
 *                 .build())
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-12-07T17:24:48.797Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.rds.$Module.class, fqn = "@aws-cdk/aws-rds.DatabaseClusterEngine")
public class DatabaseClusterEngine extends software.amazon.jsii.JsiiObject {

    protected DatabaseClusterEngine(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected DatabaseClusterEngine(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        AURORA = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.rds.DatabaseClusterEngine.class, "AURORA", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.rds.IClusterEngine.class));
        AURORA_MYSQL = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.rds.DatabaseClusterEngine.class, "AURORA_MYSQL", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.rds.IClusterEngine.class));
        AURORA_POSTGRESQL = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.rds.DatabaseClusterEngine.class, "AURORA_POSTGRESQL", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.rds.IClusterEngine.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public DatabaseClusterEngine() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * Creates a new plain Aurora database cluster engine.
     * <p>
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.rds.IClusterEngine aurora(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.rds.AuroraClusterEngineProps props) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.rds.DatabaseClusterEngine.class, "aurora", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.rds.IClusterEngine.class), new Object[] { java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * Creates a new Aurora MySQL database cluster engine.
     * <p>
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.rds.IClusterEngine auroraMysql(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.rds.AuroraMysqlClusterEngineProps props) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.rds.DatabaseClusterEngine.class, "auroraMysql", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.rds.IClusterEngine.class), new Object[] { java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * Creates a new Aurora PostgreSQL database cluster engine.
     * <p>
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.rds.IClusterEngine auroraPostgres(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.rds.AuroraPostgresClusterEngineProps props) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.rds.DatabaseClusterEngine.class, "auroraPostgres", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.rds.IClusterEngine.class), new Object[] { java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * The unversioned 'aurora' cluster engine.
     * <p>
     * <strong>Note</strong>: we do not recommend using unversioned engines for non-serverless Clusters,
     * as that can pose an availability risk.
     * We recommend using versioned engines created using the {&#64;link aurora()} method
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.rds.IClusterEngine AURORA;

    /**
     * The unversioned 'aurora-msql' cluster engine.
     * <p>
     * <strong>Note</strong>: we do not recommend using unversioned engines for non-serverless Clusters,
     * as that can pose an availability risk.
     * We recommend using versioned engines created using the {&#64;link auroraMysql()} method
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.rds.IClusterEngine AURORA_MYSQL;

    /**
     * The unversioned 'aurora-postgresql' cluster engine.
     * <p>
     * <strong>Note</strong>: we do not recommend using unversioned engines for non-serverless Clusters,
     * as that can pose an availability risk.
     * We recommend using versioned engines created using the {&#64;link auroraPostgres()} method
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.rds.IClusterEngine AURORA_POSTGRESQL;
}

==> rds-1.204.0-sources.jar: software/amazon/awscdk/services/rds/DatabaseClusterEngine.java <==
package software.amazon.awscdk.services.rds;

/**
 * A database cluster engine.
 * <p>
 * Provides mapping to the serverless application
 * used for secret rotation.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * Vpc vpc;
 * ServerlessCluster cluster = ServerlessCluster.Builder.create(this, "AnotherCluster")
 *         .engine(DatabaseClusterEngine.AURORA_POSTGRESQL)
 *         .parameterGroup(ParameterGroup.fromParameterGroupName(this, "ParameterGroup", "default.aurora-postgresql10"))
 *         .vpc(vpc)
 *         .scaling(ServerlessScalingOptions.builder()
 *                 .autoPause(Duration.minutes(10)) // default is to pause after 5 minutes of idle time
 *                 .minCapacity(AuroraCapacityUnit.ACU_8) // default is 2 Aurora capacity units (ACUs)
 *                 .maxCapacity(AuroraCapacityUnit.ACU_32)
 *                 .build())
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.84.0 (build 5404dcf)", date = "2023-06-19T16:30:49.108Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.rds.$Module.class, fqn = "@aws-cdk/aws-rds.DatabaseClusterEngine")
public class DatabaseClusterEngine extends software.amazon.jsii.JsiiObject {

    protected DatabaseClusterEngine(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected DatabaseClusterEngine(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        AURORA = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.rds.DatabaseClusterEngine.class, "AURORA", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.rds.IClusterEngine.class));
        AURORA_MYSQL = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.rds.DatabaseClusterEngine.class, "AURORA_MYSQL", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.rds.IClusterEngine.class));
        AURORA_POSTGRESQL = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.rds.DatabaseClusterEngine.class, "AURORA_POSTGRESQL", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.rds.IClusterEngine.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public DatabaseClusterEngine() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * Creates a new plain Aurora database cluster engine.
     * <p>
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.rds.IClusterEngine aurora(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.rds.AuroraClusterEngineProps props) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.rds.DatabaseClusterEngine.class, "aurora", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.rds.IClusterEngine.class), new Object[] { java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * Creates a new Aurora MySQL database cluster engine.
     * <p>
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.rds.IClusterEngine auroraMysql(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.rds.AuroraMysqlClusterEngineProps props) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.rds.DatabaseClusterEngine.class, "auroraMysql", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.rds.IClusterEngine.class), new Object[] { java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * Creates a new Aurora PostgreSQL database cluster engine.
     * <p>
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.rds.IClusterEngine auroraPostgres(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.rds.AuroraPostgresClusterEngineProps props) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.rds.DatabaseClusterEngine.class, "auroraPostgres", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.rds.IClusterEngine.class), new Object[] { java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * The unversioned 'aurora' cluster engine.
     * <p>
     * **Note**: we do not recommend using unversioned engines for non-serverless Clusters,
     * as that can pose an availability risk.
     * We recommend using versioned engines created using the {@link aurora()} method
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.rds.IClusterEngine AURORA;

    /**
     * The unversioned 'aurora-msql' cluster engine.
     * <p>
     * **Note**: we do not recommend using unversioned engines for non-serverless Clusters,
     * as that can pose an availability risk.
     * We recommend using versioned engines created using the {@link auroraMysql()} method
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.rds.IClusterEngine AURORA_MYSQL;

    /**
     * The unversioned 'aurora-postgresql' cluster engine.
     * <p>
     * **Note**: we do not recommend using unversioned engines for non-serverless Clusters,
     * as that can pose an availability risk.
     * We recommend using versioned engines created using the {@link auroraPostgres()} method
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.rds.IClusterEngine AURORA_POSTGRESQL;
}
